## 2.59.2 (2021-12-21)

add stripe.util.populate_headers (#6637)

fill out api methods for stripe.Customer (#6638)

fill out api stubs for stripe.Account (#6639)

fill out api stubs for stripe.SubscriptionItem (#6640)

## 2.59.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

